# Dash trace updater

[![PyPI Latest Release](https://img.shields.io/pypi/v/trace-updater.svg)](https://pypi.org/project/trace-updater/)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?)](http://makeapullrequest.com)
<!-- [![support-version](https://img.shields.io/pypi/pyversions/trace-updater)](https://img.shields.io/pypi/pyversions/trace-updater)
[![Downloads](https://pepy.tech/badge/trace-updater)](https://pepy.tech/project/trace-updater) -->

---

`TraceUpdater` is **dash component** which allows updating a `dcc.Graph` its traces.  

This component is **data efficient** as it:
- sends only the to-be-updated traces (and not the whole figure) from the back-end to the client-side
- updates only the traces that have changed (and does not redraw the whole figure)

🚨 **NOTE**: This package is tightly coupled with [predict-idlab/plotly-resampler](https://github.com/predict-idlab/plotly-resampler) 🚨

---

## Installation

| [pypi](https://pypi.org/project/trace-updater/) | `pip install trace-updater` |
| ---- | ---- |

## Usage

This is work in progress 🚧 

## Contributing

See [CONTRIBUTING.md](./CONTRIBUTING.md)

---

<p align="center">
👤 <i>Jonas Van Der Donckt</i>
</p>
